import { NonNullablePaths } from '@wix/sdk-types';

interface AccountV2 {
    /**
     * Account ID.
     * @format GUID
     */
    accountId?: string;
}
interface GetUserAccountRequest {
    /**
     * the user id that his account we query
     * @format GUID
     */
    userId?: string;
}
interface Account {
    /**
     * Account ID.
     * @format GUID
     */
    accountId?: string;
    /** Account slug - used in the free URL prefix */
    slug?: string;
    /** Account name (display) */
    accountName?: string | null;
    /**
     * DEPRECATED field of account image
     * @deprecated
     */
    accountImg?: string | null;
    /** account status */
    status?: AccountStatusWithLiterals;
    /** account owner user id */
    accountOwner?: string;
    /** account extra properties */
    accountProperties?: AccountProperties;
    /** the account creation date */
    dateCreated?: Date | null;
    /** last time account was updated */
    dateUpdated?: Date | null;
}
/** enum with all available statuses of account */
declare enum AccountStatus {
    ACTIVE = "ACTIVE",
    BLOCKED = "BLOCKED",
    DELETED = "DELETED"
}
/** @enumType */
type AccountStatusWithLiterals = AccountStatus | 'ACTIVE' | 'BLOCKED' | 'DELETED';
/** All relevant account properties */
interface AccountProperties {
    /** Whether this account is a team account. */
    isTeam?: boolean;
    /**
     * Account image (display)
     * relevant mainly for CoBranded accounts
     */
    accountImg?: string | null;
    /**
     * the account banner (display)
     * relevant mainly for CoBranded accounts
     */
    accountBanner?: string | null;
    /**
     * the account logo (display)
     * wll be shown as the account logo in the UI (top right corner, contributor list etc..)
     */
    accountLogo?: string | null;
    /**
     * account co branding flag (if exists)
     * an enum for CoBranding flag contains 4 possible options:
     * None - the account is not CoBranded
     * CoBranded - the account has a CoBranding flag
     * CoBranded_Customer_New - the account is a contributor of a CoBranded account. This account was created because of the contributor invite
     * CoBranded_Customer_Existing - the account is a contributor of a CoBranded account. This account was created before the invite of the contributor invite
     */
    coBranding?: CoBrandingWithLiterals;
    /** account's website URL (shown on co branding customers sites) */
    websiteUrl?: string | null;
    /** the id of the parent account of this account, if it has a parent */
    parentAccountId?: string | null;
}
/** co branding flag options for account */
declare enum CoBranding {
    None = "None",
    CoBranded = "CoBranded",
    CoBranded_Customer_New = "CoBranded_Customer_New",
    CoBranded_Customer_Existing = "CoBranded_Customer_Existing"
}
/** @enumType */
type CoBrandingWithLiterals = CoBranding | 'None' | 'CoBranded' | 'CoBranded_Customer_New' | 'CoBranded_Customer_Existing';
interface GetUserAccountsRequest {
    /**
     * the user id that his accounts we query
     * @format GUID
     */
    userId?: string;
    /** Limited to max 20 at a single request */
    paging?: Paging;
}
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface AccountsResponse {
    accounts?: Account[];
}
interface GetMyUserAccountsRequest {
    /** Limited to max 20 at a single request */
    paging?: Paging;
}
interface GetAccountRequest {
    /**
     * the account id that it's data should be retrieved
     * @format GUID
     */
    accountId?: string;
}
interface AccountResponse {
    account?: Account;
}
interface GetMyAccountRequest {
}
interface GetAccountsRequest {
    /**
     * the account id to retrieve
     * @format GUID
     */
    accountIds?: string[];
}
interface CreateAccountRequest {
    /** The user to create under the new account, with the roles defined in `roles`. */
    user: User;
    /**
     * Roles to be assigned to the user in the new account. To retrieve all available roles, call Get Roles Info in the Users API.
     * Default: OWNER.
     */
    roles?: string[] | null;
}
/** A User to be created under an implicitly provided accountId: must have a unique email. */
interface User {
    /** User's unique email address details. Required. */
    email?: Email;
    /** User's single sign on identity, when the user is identified via SSO authentication response token params, as specified by [OpenID Connect](https://openid.net/developers/how-connect-works/) (aka. OIDC) protocol. */
    ssoIdentities?: SsoIdentity[];
    /** Additional user details. */
    userDetails?: UserDetails;
}
/** User's email address. */
interface Email {
    /**
     * User's email address.
     * @format EMAIL
     */
    emailAddress?: string;
    /** Whether the caller has verified the user's email address. */
    isVerified?: boolean;
}
/** Single Sign On (aka. SSO) identity; user is identified via SSO authentication response token params, as specified by OpenID Connect (aka. OIDC) protocol */
interface SsoIdentity {
    /** An SSO setting (URLs, clientId, secret, etc. as required by OIDC protocol) for a specific Identity-Provider (aka. IdP) for a specific Wix account. */
    ssoId?: string;
    /**
     * User ID as stored in IdP. For example a "sub" claim of OIDC protocol,
     * or any other alternative, specified by IdP (Identity Provider).
     */
    userId?: string;
}
/** additional user details */
interface UserDetails {
    /**
     * User's first name.
     * @maxLength 64
     */
    firstName?: string | null;
    /**
     * User's last name.
     * @maxLength 64
     */
    lastName?: string | null;
    /**
     * URL to location of user's profile picture.
     * @format WEB_URL
     */
    profilePictureUrl?: string | null;
    /**
     * User's preferred language in [ISO 639-1:2002](https://en.wikipedia.org/wiki/ISO_639-1) format. For example, "en", "es".
     * @maxLength 2
     */
    language?: string | null;
    /**
     * Original Client IP from which a request was made.
     * This is useful in case where a createUser API is called by some server call, which, in turn, has been called by some client from another IP.
     * Wix checks this IP against the [OFAC sanctioned countries](https://ofac.treasury.gov/sanctions-programs-and-country-information).
     */
    clientIp?: string | null;
}
interface CreateAccountResponse {
    /** The created account. */
    account?: AccountV2;
}
interface CreateAccountForMyUserRequest {
    /** the account name */
    accountName?: string | null;
    /**
     * account image url
     * @format WEB_URL
     */
    accountImg?: string | null;
    /** whether to mark the account as `studio` */
    studio?: boolean;
}
interface CreateAccountTenantRequest {
    slug?: string | null;
}
interface CreateAccountTenantResponse {
    account?: AccountV2;
}
interface CreateAccountAndAssignUserRequest {
    /**
     * the user id for which we are creating the account
     * @format GUID
     */
    userId?: string;
    /** the user name of the user for which the account is created */
    userName?: string;
    /**
     * the parent account of the created account
     * @format GUID
     */
    parentAccountId?: string | null;
    /** whether to mark the account as `studio` */
    studio?: boolean;
}
interface UpdateAccountRequest {
    /**
     * the account id to update
     * @format GUID
     */
    accountId?: string;
    /**
     * DEPRECATED field of image
     * @deprecated
     */
    accountImg?: string | null;
    /** optional - new account name */
    accountName?: string | null;
    /**
     * the new properties for the account.
     * can be passed partially - and only relevant fields will be updated
     */
    accountProperties?: AccountProperties;
}
interface UpdateParentAccountRequest extends UpdateParentAccountRequestUpdateOneOf {
    /** Removes the parent account */
    remove?: RemoveParent;
}
/** @oneof */
interface UpdateParentAccountRequestUpdateOneOf {
    /** Removes the parent account */
    remove?: RemoveParent;
}
interface RemoveParent {
}
interface UpdateParentAccountResponse {
    newParentAccountId?: string | null;
}
interface DeleteAccountRequest {
    /**
     * the account id to delete
     * @format GUID
     */
    accountId?: string;
    /** will throw exception if trying to delete the account of the last user when the value is true */
    shouldNotDeleteLastAccount?: boolean;
}
interface EmptyResponse {
}
interface UpdateSlugRequest {
    /**
     * account id
     * @format GUID
     */
    accountId?: string;
    /** new slug */
    newSlugName?: string;
}
interface IsTeamRequest {
    /**
     * the account id to check if it's a team account
     * @format GUID
     */
    accountId?: string;
}
interface IsTeamResponse {
    /** true if the account is marked as a team account, false if not */
    isTeamAccount?: boolean;
}
interface MarkAccountFlagRequest extends MarkAccountFlagRequestFlagOneOf {
    /**
     * account co branding flag (if exists)
     * an enum for CoBranding flag contains 4 possible options:
     * None - the account is not CoBranded
     * CoBranded - the account has a CoBranding flag
     * CoBranded_Customer_New - the account is a contributor of a CoBranded account. This account was created because of the contributor invite
     * CoBranded_Customer_Existing - the account is a contributor of a CoBranded account. This account was created before the invite of the contributor invite
     */
    coBranding?: CoBrandingWithLiterals;
    /**
     * the account id to mark
     * @format GUID
     */
    accountId?: string;
    /** the inviting account id in case the flag is given by an invite */
    invitedByAccountId?: string | null;
}
/** @oneof */
interface MarkAccountFlagRequestFlagOneOf {
    /**
     * account co branding flag (if exists)
     * an enum for CoBranding flag contains 4 possible options:
     * None - the account is not CoBranded
     * CoBranded - the account has a CoBranding flag
     * CoBranded_Customer_New - the account is a contributor of a CoBranded account. This account was created because of the contributor invite
     * CoBranded_Customer_Existing - the account is a contributor of a CoBranded account. This account was created before the invite of the contributor invite
     */
    coBranding?: CoBrandingWithLiterals;
}
interface GetParentAccountInfoRequest {
}
interface GetParentAccountInfoResponse {
    /** The info of the parent account, if the account has a parent */
    parentAccountInfo?: AccountInfo;
}
interface AccountInfo {
    /** The name of the account */
    name?: string | null;
    /** The url of the image of the account */
    image?: string | null;
}
interface GetSubAccountsRequest {
    /** Offset-based pagination for the response. Default page size is 20, max page size is 50 */
    paging?: Paging;
}
interface GetSubAccountsResponse {
    /** The sub accounts of the target account */
    subAccounts?: SubAccountInfo[];
    /** Metadata of the response pagination */
    pagingMetadata?: PagingMetadata;
}
interface SubAccountInfo {
    /** The id of the sub account */
    accountId?: string;
}
interface PagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
}
interface ListChildAccountsRequest {
    /**
     * Paging options to limit and offset the number of items.
     * Default: 20. Max: 50.
     */
    paging?: Paging;
}
interface ListChildAccountsResponse {
    /** The requested child accounts. */
    childAccounts?: AccountV2[];
    /** Metadata of the response pagination. */
    pagingMetadata?: PagingMetadata;
}
interface SetIsReadOnlyAccountRequest {
    /** @format GUID */
    accountId?: string;
    isReadOnly?: boolean;
}
type AccountNonNullablePaths = `accountId`;
/**
 * Creates a new Wix account, and creates a new Wix user as the account owner.
 * The newly created account is a child account of the account used to create it, making that account its parent.
 *
 * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
 * @param user - The user to create under the new account, with the roles defined in `roles`.
 * @public
 * @requiredField user
 * @param options - Filter options.
 * @permissionId ACCOUNT.CREATE_ACCOUNT
 * @fqn com.wixpress.account.api.AccountService.createAccount
 */
declare function createAccount(user: User, options?: CreateAccountOptions): Promise<NonNullablePaths<CreateAccountResponse, {
    [P in AccountNonNullablePaths]: `account.${P}`;
}[AccountNonNullablePaths]>>;
interface CreateAccountOptions {
    /**
     * Roles to be assigned to the user in the new account. To retrieve all available roles, call Get Roles Info in the Users API.
     * Default: OWNER.
     */
    roles?: string[] | null;
}
interface CreateAccountForMyUserOptions {
    /** the account name */
    accountName?: string | null;
    /**
     * account image url
     * @format WEB_URL
     */
    accountImg?: string | null;
    /** whether to mark the account as `studio` */
    studio?: boolean;
}
/**
 * Retrieves a list of child account IDs for the requesting account.
 * If no child accounts exist, an empty list will be returned.
 *
 * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
 * @public
 * @param options - Filter options.
 * @permissionId ACCOUNT.CHILD_ACCOUNTS_LIST
 * @fqn com.wixpress.account.api.AccountService.listChildAccounts
 */
declare function listChildAccounts(options?: ListChildAccountsOptions): Promise<NonNullablePaths<ListChildAccountsResponse, {
    [P in AccountNonNullablePaths]: `childAccounts.${number}.${P}`;
}[AccountNonNullablePaths]>>;
interface ListChildAccountsOptions {
    /**
     * Paging options to limit and offset the number of items.
     * Default: 20. Max: 50.
     */
    paging?: Paging;
}

export { type Account, type AccountInfo, type AccountProperties, type AccountResponse, AccountStatus, type AccountStatusWithLiterals, type AccountV2, type AccountsResponse, CoBranding, type CoBrandingWithLiterals, type CreateAccountAndAssignUserRequest, type CreateAccountForMyUserOptions, type CreateAccountForMyUserRequest, type CreateAccountOptions, type CreateAccountRequest, type CreateAccountResponse, type CreateAccountTenantRequest, type CreateAccountTenantResponse, type DeleteAccountRequest, type Email, type EmptyResponse, type GetAccountRequest, type GetAccountsRequest, type GetMyAccountRequest, type GetMyUserAccountsRequest, type GetParentAccountInfoRequest, type GetParentAccountInfoResponse, type GetSubAccountsRequest, type GetSubAccountsResponse, type GetUserAccountRequest, type GetUserAccountsRequest, type IsTeamRequest, type IsTeamResponse, type ListChildAccountsOptions, type ListChildAccountsRequest, type ListChildAccountsResponse, type MarkAccountFlagRequest, type MarkAccountFlagRequestFlagOneOf, type Paging, type PagingMetadata, type RemoveParent, type SetIsReadOnlyAccountRequest, type SsoIdentity, type SubAccountInfo, type UpdateAccountRequest, type UpdateParentAccountRequest, type UpdateParentAccountRequestUpdateOneOf, type UpdateParentAccountResponse, type UpdateSlugRequest, type User, type UserDetails, createAccount, listChildAccounts };
